@@ -12,14 +12,20 @@ CConfigManager::CConfigManager() : m_inotifyFd(inotify_init()) {
 
     m_config->addConfigValue("general:grab_focus", Hyprlang::INT{1});
 
+    m_config->addConfigValue("locale:override", Hyprlang::STRING{""});
+
     m_config->addConfigValue("cache:enabled", Hyprlang::INT{1});
 
     m_config->addConfigValue("finders:default_finder", Hyprlang::STRING{"desktop"});
     m_config->addConfigValue("finders:desktop_prefix", Hyprlang::STRING{""});
     m_config->addConfigValue("finders:unicode_prefix", Hyprlang::STRING{"."});
     m_config->addConfigValue("finders:math_prefix", Hyprlang::STRING{"="});
+    m_config->addConfigValue("finders:font_prefix", Hyprlang::STRING{"'"});
 
     m_config->addConfigValue("finders:desktop_launch_prefix", Hyprlang::STRING{""});
+    m_config->addConfigValue("finders:desktop_icons", Hyprlang::INT{1});
+
+    m_config->addConfigValue("ui:window_size", Hyprlang::VEC2{400, 260});
 
     m_config->commence();
 
