@@ -15,15 +15,18 @@ using namespace Hyprutils::Memory;
 constexpr const size_t CACHE_MAX_SIZE = 512;
 
 CEntryCache::CEntryCache(const std::string& name) {
-    const auto HOME = getenv("HOME");
-
-    if (!HOME)
+    std::filesystem::path cacheDirectory;
+    if (const auto XDG_DATA_HOME = getenv("XDG_DATA_HOME"); XDG_DATA_HOME && XDG_DATA_HOME[0] != '\0')
+        cacheDirectory = std::filesystem::path{XDG_DATA_HOME} / "hyprlauncher";
+    else if (const auto HOME = getenv("HOME"))
+        cacheDirectory = std::filesystem::path{HOME} / ".local" / "share" / "hyprlauncher";
+    else
         return;
 
     std::error_code ec;
-    if (!std::filesystem::exists(HOME + std::string{"/.local/share/hyprlauncher"}, ec) || ec)
-        std::filesystem::create_directories(HOME + std::string{"/.local/share/hyprlauncher"});
-    m_cacheFullPath = HOME + std::string{"/.local/share/hyprlauncher/" + name + ".cache"};
+    if (!std::filesystem::is_directory(cacheDirectory, ec) || ec)
+        std::filesystem::create_directories(cacheDirectory);
+    m_cacheFullPath = cacheDirectory / (name + ".cache");
 
     // load cache
     std::ifstream ifs(m_cacheFullPath);
@@ -82,4 +85,4 @@ void CEntryCache::save() {
     for (const auto& s : m_cacheStrings) {
         ofs << std::format("{}\n", s);
     }
-}
\ No newline at end of file
+}
